==> mail-1.0.tar.gz: mail-1.0/source/javax/mail/event/FolderAdapter.java <==
/*
 * FolderAdapter.java
 * Copyright (C) 2002 The Free Software Foundation
 * 
 * This file is part of GNU JavaMail, a library.
 * 
 * GNU JavaMail is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * GNU JavaMail is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * As a special exception, if you link this library with other files to
 * produce an executable, this library does not by itself cause the
 * resulting executable to be covered by the GNU General Public License.
 * This exception does not however invalidate any other reasons why the
 * executable file might be covered by the GNU General Public License.
 */

package javax.mail.event;

/**
 * The adapter which receives Folder events.
 * The methods in this class are empty; this class is provided 
 * as a convenience for easily creating listeners by extending this class 
 * and overriding only the methods of interest.
 *
 * @author <a href="mailto:dog@gnu.org">Chris Burdess</a>
 * @version 1.3
 */
public abstract class FolderAdapter
  implements FolderListener
{

  /**
   * Invoked when a Folder is created.
   */
  public void folderCreated(FolderEvent e)
  {
  }

  /**
   * Invoked when a folder is renamed.
   */
  public void folderRenamed(FolderEvent e)
  {
  }

  /**
   * Invoked when a folder is deleted.
   */
  public void folderDeleted(FolderEvent e)
  {
  }

}

==> mail-1.1.tar.gz: mail-1.1/source/javax/mail/event/FolderAdapter.java <==
/*
 * FolderAdapter.java
 * Copyright (C) 2002 The Free Software Foundation
 * 
 * This file is part of GNU JavaMail, a library.
 * 
 * GNU JavaMail is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * GNU JavaMail is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * As a special exception, if you link this library with other files to
 * produce an executable, this library does not by itself cause the
 * resulting executable to be covered by the GNU General Public License.
 * This exception does not however invalidate any other reasons why the
 * executable file might be covered by the GNU General Public License.
 */

package javax.mail.event;

/**
 * An adapter for folder events.
 *
 * @author <a href="mailto:dog@gnu.org">Chris Burdess</a>
 * @version 1.3
 */
public abstract class FolderAdapter
  implements FolderListener
{

  /**
   * A folder was created.
   */
  public void folderCreated(FolderEvent e)
  {
  }

  /**
   * A folder was renamed.
   */
  public void folderRenamed(FolderEvent e)
  {
  }

  /**
   * A folder was deleted.
   */
  public void folderDeleted(FolderEvent e)
  {
  }

}
